<template>
  <div>
    <el-table
        :data="tableData"
        :class="{tableTopLevel1: topLevel === 1, tableTopLevel2: topLevel === 2, tableTopLevel3: topLevel === 3, tableTopLevelDefault: topLevel === -1}"
        row-key="id"
        border
        max-height="510"
        @selection-change="handleSelectionChange">
      <el-table-column
          fixed
          type="selection"
          width="55">
      </el-table-column>
      <el-table-column
          fixed
          prop="dictLabel"
          label="字典标签"
          sortable
          width="160">
      </el-table-column>
      <el-table-column
          prop="dictValue"
          label="字典数值"
          sortable
          width="120">
      </el-table-column>
      <el-table-column
          prop="dictStatus"
          label="状态"
          :formatter="statusFormtter"
          width="100">
      </el-table-column>
      <el-table-column
          prop="dictSort"
          label="排序"
          width="100">
      </el-table-column>
      <el-table-column
          prop="isDefault"
          label="是否默认值"
          :formatter="defaultFormtter"
          width="100">
      </el-table-column>
      <el-table-column
          prop="gmtCreate"
          label="创建时间"
          width="160">
      </el-table-column>
      <el-table-column
          prop="createBy"
          label="创建人"
          width="140">
      </el-table-column>
      <el-table-column
          label="操作">
        <template slot-scope="scope">
          <el-button v-if="editShow" type="primary" @click="editDictData(scope.row.id)" size="mini">修改</el-button>
          <el-button v-if="delShow" type="primary" @click="deleteDictData(scope.row.id)" size="mini">删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    <PageC
        :handleSizeChange="handleSizeChange"
        :handleCurrentChange="handleCurrentChange"
        :pageSize="pageSize"
        :total="total"
        :currentPage="currentPage"></PageC>
  </div>
</template>

<script>
import {getDictDatas, deleteDictDataById, getDictDataByType} from "@/api/dict-data";
import PageC from "@/components/PageC";
import {Message} from "element-ui";

export default {
  name: "DictDataTable",
  components: {PageC},
  data() {
    return {
      dictTypeId: this.$route.params.id,
    }
  },
  props: {
    topLevel: {
      required: false,
      default: -1,
      type: Number
    },
    editShow: {
      required: true,
      default: false,
      type: Boolean
    },
    delShow: {
      required: true,
      default: false,
      type: Boolean
    },
  },
  computed: {
    tableData: {
      get() {
        return this.$store.state.dictData.tableData;
      },
      set(value) {
        this.$store.state.dictData.tableData = value;
      }
    },
    // 选中行id
    multipleSelection: {
      get() {
        return this.$store.state.dictData.multipleSelection;
      },
      set(value) {
        this.$store.state.dictData.multipleSelection = value;
      }
    },
    total: {
      get() {
        return this.$store.state.dictType.total;
      },
      set(value) {
        this.$store.state.dictType.total = value;
      }
    },
    pageSize: {
      get() {
        return this.$store.state.dictType.pageSize;
      },
      set(value) {
        this.$store.state.dictType.pageSize = value;
      }
    },
    currentPage: {
      get() {
        return this.$store.state.dictType.currentPage;
      },
      set(value) {
        this.$store.state.dictType.currentPage = value;
      }
    }
  },
  methods: {
    defaultFormtter(row) {
      return row.isDefault === "0" ? "是" : "否"
    },
    statusFormtter(row) {
      return row.dictStatus === "0" ? "正常":"禁用"
    },
    handleSelectionChange(val) {
      this.multipleSelection = val.map((item) => {return item.id;})
    },
    getDictDatas() {
      let params = {
        currentPage: this.currentPage,
        pageSize: this.pageSize
      };
      // 刷新
      getDictDatas(params).then((res) => {
        this.tableData = res.data.data;
        this.total = res.data.total;
      })
    },
    editDictData(id) {
      this.$store.dispatch("dictData/editDictData", id);
    },
    deleteDictData(id) {
      this.$confirm('此操作将永久删除该字典类型, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        deleteDictDataById(id).then((res) => {
          Message.success(res.data.msg);
          this.getDictDataByType();
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '已取消删除'
        });
      });
    },
    getDictDataByType() {
      let params = {
        dictTypeId: this.dictTypeId,
        current: this.current,
        size: this.size
      }
      getDictDataByType(params).then((res) => {
        this.tableData = res.data.data;
        this.total = res.data.total;
      })
    },
    handleSizeChange(val) {
      this.pageSize = val;
      this.getDictDataByType();
    },
    handleCurrentChange(val) {
      this.currentPage = val;
      this.getDictDataByType();
    }
  },
  created() {
    if (this.$getButtonAuth('dict:data:page')) {
      this.getDictDataByType();
    }
  }
}
</script>

<style scoped>

</style>
